@@ -365,7 +365,7 @@ class Handler(object):
         elif hasattr(self, "rdflib"):
             prefixes = ["PREFIX %s: <%s>" % (k, namespaces[k]) for k in namespaces]
             q = "\n".join(prefixes) + "\n" + q
-            return rdflib.query(q)
+            return self.rdflib.query(q)
         else:
             raise AttributeError("No SPARQL Implementations")
 
