@@ -88,8 +88,8 @@ class RDFLib(HandlerPlugin):
         del self[g]
 
     def query(self, *av, **kw):
-        if hasattr(self.store, "sparql_query"):
-            return self.store.sparql_query(*av, **kw)
+        if hasattr(self.store, "query"):
+            return self.store.query(*av, **kw)
         else:
             g = ConjunctiveGraph(self.store)
             return g.query(*av, **kw)
