@@ -189,6 +189,9 @@ class predicate(property):
     >>> norman.name = Literal("Norman Bethune")
     >>> [str(x) for x in norman.name]
     ['Norman Bethune']
+    >>> norman.name = [Literal('Bob Smith')]
+    >>> [str(x) for x in norman.name]
+    ['Bob Smith']
     >>> del norman.name
     >>> len(list(norman.name))
     0
@@ -205,6 +208,8 @@ class predicate(property):
         if not value: return
         if not isinstance(value, list) and not isinstance(value, tuple):
             value = (value,)
+        else:
+            obj.graph.remove((obj.identifier, self.term, None))
         for x in value:
             if hasattr(x, "identifier") and isinstance(x.identifier, Node):
                 x = x.identifier
